summary refs log tree commit diff stats
path: root/src/cli.rs
diff options
context:
space:
mode:
Diffstat (limited to 'src/cli.rs')
-rw-r--r--src/cli.rs11
1 files changed, 9 insertions, 2 deletions
diff --git a/src/cli.rs b/src/cli.rs
index b3ee30c..12419d6 100644
--- a/src/cli.rs
+++ b/src/cli.rs
@@ -39,13 +39,20 @@ pub enum What {
         /// chapter already.
         #[arg(long, short)]
         chapter: Option<String>,
-        /// Name of the new Section
+
+        /// Name of the new section
         name: String,
     },
 
     /// Adds a chapter
     Chapter {
-        /// Name of the new Chapter
+        /// Name of the new chapter
+        name: String,
+    },
+
+    /// Adds a figure
+    Figure {
+        /// Name of the new figure
         name: String,
     },
 }